grade

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 22, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package grade computes per-axis A–F grades from a list of findings using the worst-finding-wins algorithm with per-axis caps.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CanonicalMetadata

func CanonicalMetadata() string

CanonicalMetadata returns a stable string form of caps + templates used by the registry checksum to detect tampering with grade calculation rules.

func Grade

func Grade(axis axes.Axis, findings []model.Finding) model.AxisResult

Grade computes the AxisResult for one axis given a slice of findings (the function filters internally — caller may pass all findings).

Types

This section is empty.

Jump to